@@ -33,7 +33,7 @@ class BaseQuery(object):
       self.connector.__setattr__(k, kwargs[k])
 
     for k in optional:
-      if k in optional:
+      if k in kwargs.keys():
         self.__setattr__(k, kwargs[k])
         self.connector.__setattr__(k, kwargs[k])
 
