@@ -1,5 +1,5 @@
 import gdata.analytics.service
-from dbconf import dbs
+from dbs import dbs
 class googleAnalytics(object):
 
 
